# QuickStart_Rhy

```shell
pip3 install quickstart-rhy                                         # stable version
pip3 install git+https://github.com/Rhythmicc/quickstart-rhy.git -U # beta version but more features
```

| Key  | Value                                              |
| :--: | -------------------------------------------------- |
| ENV  | **^Python 3.7**                                    |
| FONT | **Cascadia Code / Meslo**                          |
| DOCS | <https://rhythmlian.cn/2020/02/14/QuickStart-Rhy/> |

## Tab Complete

1. fig

   ```shell
   npx @fig/publish-spec -p complete/fig/qs-<your language>.ts --name qs
   ```

2. zsh

   ```shell
   mv _qs /path/in/$FPATH/
   ```
